@@ -29,7 +29,7 @@ end
 
 def pre_filter(decl)
   case $method_name
-  when /(^ud|^ue)/
+  when /(^ud|^ue|^ui)/
     # replace MX with NX
     decl.gsub!('MX','NX')
   when /^ug/
