@@ -1,14 +1,27 @@
 /*
  * dcl_obj2cary.c
- *   $Id: dcl_obj2cary.c,v 1.2 2000/11/12 00:37:37 keiko Exp $
+ *   $Id: dcl_obj2cary.c,v 1.1.1.1 2011-02-23 07:21:26 horinout Exp $
  */
 
 #include <math.h>
 #include "ruby.h"
-#include "version.h"
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef RFLOAT_VALUE
+#define RFLOAT_VALUE(x) ((real)(RFLOAT(x)->value))
+#endif
+#ifndef RARRAY_PTR
+#define RARRAY_PTR(a) (RARRAY(a)->ptr)
+#endif
+#ifndef RARRAY_LEN
+#define RARRAY_LEN(a) (RARRAY(a)->len)
+#endif
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 extern VALUE mDCL;
 
 /*  functions  */
@@ -41,7 +54,7 @@ static complex *na2ccomplexary(VALUE);
 
 /*  defines  */
 #define BE_INTEGER(x) ((integer)(NUM2INT(rb_Integer(x))))
-#define BE_REAL(x)    ((real)(RFLOAT(rb_Float(x))->value))
+#define BE_REAL(x)    ((real)(RFLOAT_VALUE(rb_Float(x))))
 #define BE_LOGICAL(x) (((x == Qnil) || (x == Qfalse)) ? FALSE_ : TRUE_ )
 /* not implemented 
 #define BE_COMPLEX(x) ...
@@ -109,12 +122,14 @@ dcl_obj2crealary(src)
     VALUE chk;
     real *rtn;
     char *klass;
+    VALUE klass_tmp;
     VALUE rmiss;
 
     switch (TYPE(src)){
     case T_OBJECT:
-	klass = STR2CSTR( rb_funcall(rb_funcall(src, rb_intern("class"),0),
-				     rb_intern("to_s"),0) );
+	klass_tmp = rb_funcall(rb_funcall(src, rb_intern("class"),0),
+				     rb_intern("to_s"),0);
+	klass = StringValuePtr(klass_tmp);
 	if (strncmp(klass,"NArrayMiss",10) != 0) {
 	    rb_raise(rb_eTypeError, "a numeric array expected");
 	}
@@ -268,24 +283,34 @@ ary2ccharary(src, size, charlen)
 {
     VALUE *ptr;
     long len, i, j;
-#if RUBY_VERSION_CODE > 170
+#ifdef StringValue
+    // Ruby version 1.8 or later
     long rlen;
 #else
+    // Ruby version 1.7 or before
     int rlen;
 #endif
     char *rtn, *wk, *rwk;
 
     Check_Type(src, T_ARRAY);
 
-    len = RARRAY(src)->len;
-    ptr = RARRAY(src)->ptr;
+    len = RARRAY_LEN(src);
+    ptr = RARRAY_PTR(src);
 
     rtn = ALLOC_N(char, size);
     memset(rtn, '\0', size);
     wk = rtn;
     for (i = 0; i < len; i++) {
-	rwk = rb_str2cstr(ptr[i], &rlen);
-	j = rlen;
+#ifdef StringValue
+        // Ruby version 1.8 or later
+        StringValue(ptr[i]);
+        rwk = RSTRING_PTR(ptr[i]);
+        rlen = RSTRING_LEN(ptr[i]);
+#else
+        // Ruby version 1.7 or before
+        rwk = rb_str2cstr(ptr[i], &rlen);
+#endif
+        j = rlen;
         strncpy(wk, rwk, charlen);
         while (j < charlen) {
             wk[j++] = ' ';
@@ -305,8 +330,8 @@ ary2cintegerary(src)
 
     Check_Type(src, T_ARRAY);
 
-    len = RARRAY(src)->len;
-    ptr = RARRAY(src)->ptr;
+    len = RARRAY_LEN(src);
+    ptr = RARRAY_PTR(src);
 
     rtn = ALLOC_N(integer, len);
 
@@ -327,8 +352,8 @@ ary2crealary(src)
 
     Check_Type(src, T_ARRAY);
 
-    len = RARRAY(src)->len;
-    ptr = RARRAY(src)->ptr;
+    len = RARRAY_LEN(src);
+    ptr = RARRAY_PTR(src);
 
     rtn = ALLOC_N(real, len);
 
@@ -350,8 +375,8 @@ ary2ccomplexary(src)
 
     Check_Type(src, T_ARRAY);
 
-    len = RARRAY(src)->len;
-    ptr = RARRAY(src)->ptr;
+    len = RARRAY_LEN(src);
+    ptr = RARRAY_PTR(src);
 
     rtn = ALLOC_N(complex, len);
 
@@ -373,8 +398,8 @@ ary2clogicalary(src)
 
     Check_Type(src, T_ARRAY);
 
-    len = RARRAY(src)->len;
-    ptr = RARRAY(src)->ptr;
+    len = RARRAY_LEN(src);
+    ptr = RARRAY_PTR(src);
 
     rtn = ALLOC_N(logical, len);
 
