@@ -1,7 +1,7 @@
 #
 # scpkt7.rb
 #
-# $Id: scpkt7.rb,v 1.1 2000/11/21 03:02:06 keiko Exp $
+# $Id: scpkt7.rb,v 1.2 2011-02-23 15:21:41 koshiro Exp $
 #
 
 require "narray"
@@ -25,7 +25,7 @@ a = NArray.sfloat(nx)
 
 #-- data ---
 alon.indgen(xmin, (xmax-xmin)/(nx-1).to_f)
-alat = alat.indgen(ymin) * (  (ymax-ymin)/(nx-1).to_f )
+alat = alat.indgen * (  (ymax-ymin)/(nx-1).to_f ) + ymin
 r.fill!(1.0)
 
 #-- graph ---
