@@ -430,6 +430,42 @@ dcl_stsrad(obj, lxdeg, lydeg)
 
 }
 
+#if DCLVER >= 544
+
+static VALUE
+dcl_stfusr(obj, xlon, ylat)
+    VALUE obj, xlon, ylat;
+{
+    real i_xlon;
+    real i_ylat;
+    real o_xx;
+    real o_yy;
+    VALUE xx;
+    VALUE yy;
+
+    if (TYPE(xlon) != T_FLOAT) {
+      xlon = rb_funcall(xlon, rb_intern("to_f"), 0);
+    }
+    if (TYPE(ylat) != T_FLOAT) {
+      ylat = rb_funcall(ylat, rb_intern("to_f"), 0);
+    }
+
+    i_xlon = (real)NUM2DBL(xlon);
+    i_ylat = (real)NUM2DBL(ylat);
+
+
+    stfusr_(&i_xlon, &i_ylat, &o_xx, &o_yy);
+
+    xx = rb_float_new((double)o_xx);
+    yy = rb_float_new((double)o_yy);
+
+
+    return rb_ary_new3(2, xx, yy);
+
+}
+
+#else
+
 static VALUE
 dcl_stfusr(obj, ux, uy)
     VALUE obj, ux, uy;
@@ -462,6 +498,44 @@ dcl_stfusr(obj, ux, uy)
 
 }
 
+#endif
+
+#if DCLVER >= 544
+
+static VALUE
+dcl_stiusr(obj, xx, yy)
+    VALUE obj, xx, yy;
+{
+    real i_xx;
+    real i_yy;
+    real o_xlon;
+    real o_ylat;
+    VALUE xlon;
+    VALUE ylat;
+
+    if (TYPE(xx) != T_FLOAT) {
+      xx = rb_funcall(xx, rb_intern("to_f"), 0);
+    }
+    if (TYPE(yy) != T_FLOAT) {
+      yy = rb_funcall(yy, rb_intern("to_f"), 0);
+    }
+
+    i_xx = (real)NUM2DBL(xx);
+    i_yy = (real)NUM2DBL(yy);
+
+
+    stiusr_(&i_xx, &i_yy, &o_xlon, &o_ylat);
+
+    xlon = rb_float_new((double)o_xlon);
+    ylat = rb_float_new((double)o_ylat);
+
+
+    return rb_ary_new3(2, xlon, ylat);
+
+}
+
+#else
+
 static VALUE
 dcl_stiusr(obj, xx, yy)
     VALUE obj, xx, yy;
@@ -494,6 +568,8 @@ dcl_stiusr(obj, xx, yy)
 
 }
 
+#endif
+
 static VALUE
 dcl_stsusr(obj)
     VALUE obj;
@@ -504,6 +580,59 @@ dcl_stsusr(obj)
 
 }
 
+#if DCLVER >= 544
+
+static VALUE
+dcl_stnusr(obj, kproj)
+    VALUE obj, kproj;
+{
+    integer i_kproj;
+
+    if ((TYPE(kproj) != T_BIGNUM) || (TYPE(kproj) != T_FIXNUM)) {
+      kproj = rb_funcall(kproj, rb_intern("to_i"), 0);
+    }
+
+    i_kproj = NUM2INT(kproj);
+
+
+    stnusr_(&i_kproj);
+
+    return Qnil;
+
+}
+
+#endif
+
+#if DCLVER >= 544
+
+static VALUE
+dcl_stcusr(obj, i)
+    VALUE obj, i;
+{
+    integer i_i;
+    char *o_cttl;
+    VALUE cttl;
+
+    if ((TYPE(i) != T_BIGNUM) || (TYPE(i) != T_FIXNUM)) {
+      i = rb_funcall(i, rb_intern("to_i"), 0);
+    }
+
+    i_i = NUM2INT(i);
+
+    o_cttl= ALLOCA_N(char, (DFLT_SIZE+1));
+    memset(o_cttl, '\0', DFLT_SIZE+1);
+
+    stcusr_(&i_i, o_cttl, (ftnlen)DFLT_SIZE);
+
+    cttl = rb_str_new2(o_cttl);
+
+
+    return cttl;
+
+}
+
+#endif
+
 static VALUE
 dcl_stfwtr(obj, rx, ry)
     VALUE obj, rx, ry;
@@ -1023,9 +1152,21 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "stfrad", dcl_stfrad, 2);
     rb_define_module_function(mDCL, "stirad", dcl_stirad, 2);
     rb_define_module_function(mDCL, "stsrad", dcl_stsrad, 2);
+#if DCLVER >= 544
     rb_define_module_function(mDCL, "stfusr", dcl_stfusr, 2);
+    rb_define_module_function(mDCL, "stfusr", dcl_stfusr, 2);
+#endif
+#if DCLVER >= 544
     rb_define_module_function(mDCL, "stiusr", dcl_stiusr, 2);
+    rb_define_module_function(mDCL, "stiusr", dcl_stiusr, 2);
+#endif
     rb_define_module_function(mDCL, "stsusr", dcl_stsusr, 0);
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "stnusr", dcl_stnusr, 1);
+#endif
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "stcusr", dcl_stcusr, 1);
+#endif
     rb_define_module_function(mDCL, "stfwtr", dcl_stfwtr, 2);
     rb_define_module_function(mDCL, "stiwtr", dcl_stiwtr, 2);
     rb_define_module_function(mDCL, "stswtr", dcl_stswtr, 9);
