@@ -81,6 +81,46 @@ dcl_swdcls(obj)
 
 }
 
+#if DCLVER >= 544
+
+static VALUE
+dcl_swqfcc(obj)
+    VALUE obj;
+{
+    logical o_lfcatr;
+    VALUE lfcatr;
+
+    swqfcc_(&o_lfcatr);
+
+    lfcatr = (o_lfcatr == FALSE_) ? Qfalse : Qtrue;
+
+
+    return lfcatr;
+
+}
+
+#endif
+
+#if DCLVER >= 544
+
+static VALUE
+dcl_swsfcm(obj)
+    VALUE obj;
+{
+    logical o_lfcmod;
+    VALUE lfcmod;
+
+    swsfcm_(&o_lfcmod);
+
+    lfcmod = (o_lfcmod == FALSE_) ? Qfalse : Qtrue;
+
+
+    return lfcmod;
+
+}
+
+#endif
+
 static VALUE
 dcl_swpopn(obj)
     VALUE obj;
@@ -163,6 +203,31 @@ dcl_swswdi(obj, iwdidx)
 
 }
 
+#if DCLVER >= 544
+
+static VALUE
+dcl_swscli(obj, iclidx, lfcatr)
+    VALUE obj, iclidx, lfcatr;
+{
+    integer i_iclidx;
+    logical i_lfcatr;
+
+    if ((TYPE(iclidx) != T_BIGNUM) || (TYPE(iclidx) != T_FIXNUM)) {
+      iclidx = rb_funcall(iclidx, rb_intern("to_i"), 0);
+    }
+
+    i_iclidx = NUM2INT(iclidx);
+    i_lfcatr = ((lfcatr == Qnil)||(lfcatr == Qfalse)) ? FALSE_ : TRUE_;
+
+
+    swscli_(&i_iclidx, &i_lfcatr);
+
+    return Qnil;
+
+}
+
+#else
+
 static VALUE
 dcl_swscli(obj, iclidx)
     VALUE obj, iclidx;
@@ -182,6 +247,31 @@ dcl_swscli(obj, iclidx)
 
 }
 
+#endif
+
+#if DCLVER >= 544
+
+static VALUE
+dcl_swslcl(obj, icolor)
+    VALUE obj, icolor;
+{
+    integer i_icolor;
+
+    if ((TYPE(icolor) != T_BIGNUM) || (TYPE(icolor) != T_FIXNUM)) {
+      icolor = rb_funcall(icolor, rb_intern("to_i"), 0);
+    }
+
+    i_icolor = NUM2INT(icolor);
+
+
+    swslcl_(&i_icolor);
+
+    return Qnil;
+
+}
+
+#endif
+
 static VALUE
 dcl_swgopn(obj)
     VALUE obj;
@@ -250,6 +340,29 @@ dcl_swgcls(obj)
 
 }
 
+#if DCLVER >= 544
+
+static VALUE
+dcl_swstcl(obj, icolor)
+    VALUE obj, icolor;
+{
+    integer i_icolor;
+
+    if ((TYPE(icolor) != T_BIGNUM) || (TYPE(icolor) != T_FIXNUM)) {
+      icolor = rb_funcall(icolor, rb_intern("to_i"), 0);
+    }
+
+    i_icolor = NUM2INT(icolor);
+
+
+    swstcl_(&i_icolor);
+
+    return Qnil;
+
+}
+
+#endif
+
 static VALUE
 dcl_swgton(obj, np, wpx, wpy, itpat)
     VALUE obj, np, wpx, wpy, itpat;
@@ -359,6 +472,40 @@ dcl_swidat(obj, image, nlen)
 
 }
 
+#if DCLVER >= 544
+
+static VALUE
+dcl_swiclr(obj, image, nlen)
+    VALUE obj, image, nlen;
+{
+    integer *i_image;
+    integer i_nlen;
+
+    if ((TYPE(image) == T_BIGNUM) || (TYPE(image) == T_FIXNUM)) {
+      image = rb_Array(image);
+    }
+    /* if ((TYPE(image) != T_ARRAY) && 
+           (rb_obj_is_kind_of(image, cNArray) != Qtrue)) {
+         rb_raise(rb_eTypeError, "invalid type");
+       }  -- no check since obj2c*ary will do that */
+    if ((TYPE(nlen) != T_BIGNUM) || (TYPE(nlen) != T_FIXNUM)) {
+      nlen = rb_funcall(nlen, rb_intern("to_i"), 0);
+    }
+
+    i_nlen = NUM2INT(nlen);
+    i_image = dcl_obj2cintegerary(image);
+
+
+    swiclr_(i_image, &i_nlen);
+
+    dcl_freecintegerary(i_image);
+
+    return Qnil;
+
+}
+
+#endif
+
 static VALUE
 dcl_swicls(obj)
     VALUE obj;
@@ -582,6 +729,20 @@ dcl_swsrot(obj, iwtrot)
 
 }
 
+#if DCLVER >= 544
+
+static VALUE
+dcl_swclch(obj)
+    VALUE obj;
+{
+    swclch_();
+
+    return Qnil;
+
+}
+
+#endif
+
 static VALUE
 dcl_swpqnp(obj)
     VALUE obj;
@@ -1834,19 +1995,37 @@ VALUE mDCL;
 {
     rb_define_module_function(mDCL, "swdopn", dcl_swdopn, 0);
     rb_define_module_function(mDCL, "swdcls", dcl_swdcls, 0);
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "swqfcc", dcl_swqfcc, 0);
+#endif
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "swsfcm", dcl_swsfcm, 0);
+#endif
     rb_define_module_function(mDCL, "swpopn", dcl_swpopn, 0);
     rb_define_module_function(mDCL, "swpcls", dcl_swpcls, 0);
     rb_define_module_function(mDCL, "swoopn", dcl_swoopn, 2);
     rb_define_module_function(mDCL, "swocls", dcl_swocls, 1);
     rb_define_module_function(mDCL, "swswdi", dcl_swswdi, 1);
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "swscli", dcl_swscli, 2);
     rb_define_module_function(mDCL, "swscli", dcl_swscli, 1);
+#endif
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "swslcl", dcl_swslcl, 1);
+#endif
     rb_define_module_function(mDCL, "swgopn", dcl_swgopn, 0);
     rb_define_module_function(mDCL, "swgmov", dcl_swgmov, 2);
     rb_define_module_function(mDCL, "swgplt", dcl_swgplt, 2);
     rb_define_module_function(mDCL, "swgcls", dcl_swgcls, 0);
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "swstcl", dcl_swstcl, 1);
+#endif
     rb_define_module_function(mDCL, "swgton", dcl_swgton, 4);
     rb_define_module_function(mDCL, "swiopn", dcl_swiopn, 4);
     rb_define_module_function(mDCL, "swidat", dcl_swidat, 2);
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "swiclr", dcl_swiclr, 2);
+#endif
     rb_define_module_function(mDCL, "swicls", dcl_swicls, 0);
     rb_define_module_function(mDCL, "swqpnt", dcl_swqpnt, 0);
     rb_define_module_function(mDCL, "swfint", dcl_swfint, 2);
@@ -1858,6 +2037,9 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "swqptc", dcl_swqptc, 0);
     rb_define_module_function(mDCL, "swqrct", dcl_swqrct, 0);
     rb_define_module_function(mDCL, "swsrot", dcl_swsrot, 1);
+#if DCLVER >= 544
+    rb_define_module_function(mDCL, "swclch", dcl_swclch, 0);
+#endif
     rb_define_module_function(mDCL, "swpqnp", dcl_swpqnp, 0);
     rb_define_module_function(mDCL, "swpqid", dcl_swpqid, 1);
     rb_define_module_function(mDCL, "swpqcp", dcl_swpqcp, 1);
