@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -84,7 +89,7 @@ dcl_ucpqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ucpqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -232,7 +237,7 @@ dcl_ucpqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ucpqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -262,7 +267,7 @@ dcl_ucxacl(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -291,7 +296,7 @@ dcl_ucxady(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -320,7 +325,7 @@ dcl_ucxamn(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -349,7 +354,7 @@ dcl_ucxayr(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -378,7 +383,7 @@ dcl_ucyacl(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -407,7 +412,7 @@ dcl_ucyady(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -436,7 +441,7 @@ dcl_ucyamn(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -465,7 +470,7 @@ dcl_ucyayr(obj, cside, jd0, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
     i_nd = NUM2INT(nd);
 
@@ -488,7 +493,7 @@ dcl_uciget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uciget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -514,7 +519,7 @@ dcl_uciset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -538,7 +543,7 @@ dcl_ucistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -576,7 +581,7 @@ dcl_uciqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uciqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -700,7 +705,7 @@ dcl_uciqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uciqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -724,7 +729,7 @@ dcl_uclget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uclget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -747,7 +752,7 @@ dcl_uclset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -768,7 +773,7 @@ dcl_uclstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -806,7 +811,7 @@ dcl_uclqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uclqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -927,7 +932,7 @@ dcl_uclqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uclqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -951,7 +956,7 @@ dcl_ucrget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ucrget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -977,7 +982,7 @@ dcl_ucrset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1001,7 +1006,7 @@ dcl_ucrstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1039,7 +1044,7 @@ dcl_ucrqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ucrqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1163,7 +1168,7 @@ dcl_ucrqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ucrqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
