@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -136,6 +141,50 @@ dcl_uetonf(obj, z, mx, nx, ny)
 
 }
 
+#if DCLVER >= 534
+
+static VALUE
+dcl_uetonb(obj, z, mx, nx, ny)
+    VALUE obj, z, mx, nx, ny;
+{
+    real *i_z;
+    integer i_mx;
+    integer i_nx;
+    integer i_ny;
+
+    if (TYPE(z) == T_FLOAT) {
+      z = rb_Array(z);
+    }
+    /* if ((TYPE(z) != T_ARRAY) && 
+           (rb_obj_is_kind_of(z, cNArray) != Qtrue)) {
+         rb_raise(rb_eTypeError, "invalid type");
+       }  -- no check since obj2c*ary will do that */
+    if ((TYPE(mx) != T_BIGNUM) || (TYPE(mx) != T_FIXNUM)) {
+      mx = rb_funcall(mx, rb_intern("to_i"), 0);
+    }
+    if ((TYPE(nx) != T_BIGNUM) || (TYPE(nx) != T_FIXNUM)) {
+      nx = rb_funcall(nx, rb_intern("to_i"), 0);
+    }
+    if ((TYPE(ny) != T_BIGNUM) || (TYPE(ny) != T_FIXNUM)) {
+      ny = rb_funcall(ny, rb_intern("to_i"), 0);
+    }
+
+    i_mx = NUM2INT(mx);
+    i_nx = NUM2INT(nx);
+    i_ny = NUM2INT(ny);
+    i_z = dcl_obj2crealary(z);
+
+
+    uetonb_(i_z, &i_mx, &i_nx, &i_ny);
+
+    dcl_freecrealary(i_z);
+
+    return Qnil;
+
+}
+
+#endif
+
 static VALUE
 dcl_uetonc(obj, z, mx, nx, ny)
     VALUE obj, z, mx, nx, ny;
@@ -211,7 +260,7 @@ dcl_uezchk(obj, z, mx, nx, ny, cname)
     i_mx = NUM2INT(mx);
     i_nx = NUM2INT(nx);
     i_ny = NUM2INT(ny);
-    i_cname = STR2CSTR(cname);
+    i_cname = StringValuePtr(cname);
     i_z = dcl_obj2crealary(z);
 
 
@@ -476,7 +525,7 @@ dcl_uepqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uepqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -624,7 +673,7 @@ dcl_uepqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uepqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -648,7 +697,7 @@ dcl_ueiget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ueiget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -674,7 +723,7 @@ dcl_ueiset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -698,7 +747,7 @@ dcl_ueistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -736,7 +785,7 @@ dcl_ueiqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ueiqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -860,7 +909,7 @@ dcl_ueiqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ueiqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -884,7 +933,7 @@ dcl_uelget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uelget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -907,7 +956,7 @@ dcl_uelset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -928,7 +977,7 @@ dcl_uelstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -966,7 +1015,7 @@ dcl_uelqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uelqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1087,7 +1136,7 @@ dcl_uelqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uelqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1111,7 +1160,7 @@ dcl_uerget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uerget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -1137,7 +1186,7 @@ dcl_uerset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1161,7 +1210,7 @@ dcl_uerstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1199,7 +1248,7 @@ dcl_uerqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uerqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1323,7 +1372,7 @@ dcl_uerqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uerqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1340,6 +1389,9 @@ VALUE mDCL;
 {
     rb_define_module_function(mDCL, "uetone", dcl_uetone, 4);
     rb_define_module_function(mDCL, "uetonf", dcl_uetonf, 4);
+#if DCLVER >= 534
+    rb_define_module_function(mDCL, "uetonb", dcl_uetonb, 4);
+#endif
     rb_define_module_function(mDCL, "uetonc", dcl_uetonc, 4);
     rb_define_module_function(mDCL, "uezchk", dcl_uezchk, 5);
     rb_define_module_function(mDCL, "uegtla", dcl_uegtla, 3);
