@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,34 +32,34 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
-VALUE mDCL;
+extern VALUE mDCL;
 
 static VALUE
 dcl_usgrph(obj, n, x, y)
@@ -118,10 +123,10 @@ dcl_ussttl(obj, cxttl, cxunit, cyttl, cyunit)
       cyunit = rb_funcall(cyunit, rb_intern("to_str"), 0);
     }
 
-    i_cxttl = STR2CSTR(cxttl);
-    i_cxunit = STR2CSTR(cxunit);
-    i_cyttl = STR2CSTR(cyttl);
-    i_cyunit = STR2CSTR(cyunit);
+    i_cxttl = StringValuePtr(cxttl);
+    i_cxunit = StringValuePtr(cxunit);
+    i_cyttl = StringValuePtr(cyttl);
+    i_cyunit = StringValuePtr(cyunit);
 
 
     ussttl_(i_cxttl, i_cxunit, i_cyttl, i_cyunit, (ftnlen)strlen(i_cxttl), (ftnlen)strlen(i_cxunit), (ftnlen)strlen(i_cyttl), (ftnlen)strlen(i_cyunit));
@@ -228,7 +233,7 @@ dcl_uspqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uspqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -376,7 +381,7 @@ dcl_uspqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uspqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -400,7 +405,7 @@ dcl_uscget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -428,8 +433,8 @@ dcl_uscset(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     uscset_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -452,8 +457,8 @@ dcl_uscstx(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     uscstx_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -490,7 +495,7 @@ dcl_uscqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uscqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -595,7 +600,7 @@ dcl_uscsvl(obj, idx, cval)
     }
 
     i_idx = NUM2INT(idx);
-    i_cval = STR2CSTR(cval);
+    i_cval = StringValuePtr(cval);
 
 
     uscsvl_(&i_idx, i_cval, (ftnlen)strlen(i_cval));
@@ -616,7 +621,7 @@ dcl_uscqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uscqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -676,7 +681,7 @@ dcl_usxaxs(obj, cside)
       cside = rb_funcall(cside, rb_intern("to_str"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
 
 
     usxaxs_(i_cside, (ftnlen)strlen(i_cside));
@@ -695,7 +700,7 @@ dcl_usyaxs(obj, cside)
       cside = rb_funcall(cside, rb_intern("to_str"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
 
 
     usyaxs_(i_cside, (ftnlen)strlen(i_cside));
@@ -734,7 +739,7 @@ dcl_ususcu(obj, caxis, umin, umax, vmin, vmax, mode)
       mode = rb_funcall(mode, rb_intern("to_i"), 0);
     }
 
-    i_caxis = STR2CSTR(caxis);
+    i_caxis = StringValuePtr(caxis);
     i_umin = (real)NUM2DBL(umin);
     i_umax = (real)NUM2DBL(umax);
     i_vmin = (real)NUM2DBL(vmin);
@@ -774,7 +779,7 @@ dcl_ususcl(obj, caxis, umin, umax, vmin, vmax)
       vmax = rb_funcall(vmax, rb_intern("to_f"), 0);
     }
 
-    i_caxis = STR2CSTR(caxis);
+    i_caxis = StringValuePtr(caxis);
     i_umin = (real)NUM2DBL(umin);
     i_umax = (real)NUM2DBL(umax);
     i_vmin = (real)NUM2DBL(vmin);
@@ -797,7 +802,7 @@ dcl_usxaxu(obj, cxs)
       cxs = rb_funcall(cxs, rb_intern("to_str"), 0);
     }
 
-    i_cxs = STR2CSTR(cxs);
+    i_cxs = StringValuePtr(cxs);
 
 
     usxaxu_(i_cxs, (ftnlen)strlen(i_cxs));
@@ -816,7 +821,7 @@ dcl_usxaxl(obj, cxs)
       cxs = rb_funcall(cxs, rb_intern("to_str"), 0);
     }
 
-    i_cxs = STR2CSTR(cxs);
+    i_cxs = StringValuePtr(cxs);
 
 
     usxaxl_(i_cxs, (ftnlen)strlen(i_cxs));
@@ -835,7 +840,7 @@ dcl_usyaxu(obj, cys)
       cys = rb_funcall(cys, rb_intern("to_str"), 0);
     }
 
-    i_cys = STR2CSTR(cys);
+    i_cys = StringValuePtr(cys);
 
 
     usyaxu_(i_cys, (ftnlen)strlen(i_cys));
@@ -854,7 +859,7 @@ dcl_usyaxl(obj, cys)
       cys = rb_funcall(cys, rb_intern("to_str"), 0);
     }
 
-    i_cys = STR2CSTR(cys);
+    i_cys = StringValuePtr(cys);
 
 
     usyaxl_(i_cys, (ftnlen)strlen(i_cys));
@@ -885,9 +890,9 @@ dcl_usxsub(obj, cxa, cya, clabel, rlbl)
       rlbl = rb_funcall(rlbl, rb_intern("to_f"), 0);
     }
 
-    i_cxa = STR2CSTR(cxa);
-    i_cya = STR2CSTR(cya);
-    i_clabel = STR2CSTR(clabel);
+    i_cxa = StringValuePtr(cxa);
+    i_cya = StringValuePtr(cya);
+    i_clabel = StringValuePtr(clabel);
     i_rlbl = (real)NUM2DBL(rlbl);
 
 
@@ -919,9 +924,9 @@ dcl_usysub(obj, cya, cxa, clabel, rlbl)
       rlbl = rb_funcall(rlbl, rb_intern("to_f"), 0);
     }
 
-    i_cya = STR2CSTR(cya);
-    i_cxa = STR2CSTR(cxa);
-    i_clabel = STR2CSTR(clabel);
+    i_cya = StringValuePtr(cya);
+    i_cxa = StringValuePtr(cxa);
+    i_clabel = StringValuePtr(clabel);
     i_rlbl = (real)NUM2DBL(rlbl);
 
 
@@ -953,7 +958,7 @@ dcl_csblbl(obj, ufac, uoff, cunit)
 
     i_ufac = (real)NUM2DBL(ufac);
     i_uoff = (real)NUM2DBL(uoff);
-    i_cunit = STR2CSTR(cunit);
+    i_cunit = StringValuePtr(cunit);
 
     o_rtn_val= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_rtn_val, '\0', DFLT_SIZE+1);
@@ -1003,7 +1008,7 @@ dcl_usxoff(obj, cxs)
       cxs = rb_funcall(cxs, rb_intern("to_str"), 0);
     }
 
-    i_cxs = STR2CSTR(cxs);
+    i_cxs = StringValuePtr(cxs);
 
 
     usxoff_(i_cxs, (ftnlen)strlen(i_cxs));
@@ -1022,7 +1027,7 @@ dcl_usyoff(obj, cys)
       cys = rb_funcall(cys, rb_intern("to_str"), 0);
     }
 
-    i_cys = STR2CSTR(cys);
+    i_cys = StringValuePtr(cys);
 
 
     usyoff_(i_cys, (ftnlen)strlen(i_cys));
@@ -1195,9 +1200,9 @@ dcl_usaxcl(obj, cside, jd0, ctype, nd)
       nd = rb_funcall(nd, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_jd0 = NUM2INT(jd0);
-    i_ctype = STR2CSTR(ctype);
+    i_ctype = StringValuePtr(ctype);
     i_nd = NUM2INT(nd);
 
 
@@ -1225,7 +1230,7 @@ dcl_usaxdv(obj, cside, dtick, dlbl)
       dlbl = rb_funcall(dlbl, rb_intern("to_f"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_dtick = (real)NUM2DBL(dtick);
     i_dlbl = (real)NUM2DBL(dlbl);
 
@@ -1281,7 +1286,7 @@ dcl_usaxlb(obj, cside, dtick, n1, dlabel, ch, nc, n2)
       n2 = rb_funcall(n2, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_n1 = NUM2INT(n1);
     i_nc = NUM2INT(nc);
     i_n2 = NUM2INT(n2);
@@ -1318,7 +1323,7 @@ dcl_usaxlg(obj, cside, nlbl, nticks)
       nticks = rb_funcall(nticks, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_nlbl = NUM2INT(nlbl);
     i_nticks = NUM2INT(nticks);
 
@@ -1363,7 +1368,7 @@ dcl_usaxnm(obj, cside, dtick, n1, dlabel, n2)
       n2 = rb_funcall(n2, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_n1 = NUM2INT(n1);
     i_n2 = NUM2INT(n2);
     i_dtick = dcl_obj2crealary(dtick);
@@ -1389,7 +1394,7 @@ dcl_usaxsc(obj, cside)
       cside = rb_funcall(cside, rb_intern("to_str"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
 
 
     usaxsc_(i_cside, (ftnlen)strlen(i_cside));
@@ -1410,7 +1415,7 @@ dcl_usiget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     usiget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -1436,7 +1441,7 @@ dcl_usiset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -1460,7 +1465,7 @@ dcl_usistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -1498,7 +1503,7 @@ dcl_usiqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     usiqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1622,7 +1627,7 @@ dcl_usiqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     usiqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1646,7 +1651,7 @@ dcl_uslget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uslget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -1669,7 +1674,7 @@ dcl_uslset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -1690,7 +1695,7 @@ dcl_uslstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -1728,7 +1733,7 @@ dcl_uslqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uslqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1849,7 +1854,7 @@ dcl_uslqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uslqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1875,7 +1880,7 @@ dcl_uspaxs(obj, cside, islct)
       islct = rb_funcall(islct, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_islct = NUM2INT(islct);
 
 
@@ -1922,7 +1927,7 @@ dcl_usplbl(obj, cside, islct, pos, ch, nc, n)
       n = rb_funcall(n, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_islct = NUM2INT(islct);
     i_nc = NUM2INT(nc);
     i_n = NUM2INT(n);
@@ -1965,7 +1970,7 @@ dcl_uspnum(obj, cside, islct, pos, n)
       n = rb_funcall(n, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_islct = NUM2INT(islct);
     i_n = NUM2INT(n);
     i_pos = dcl_obj2crealary(pos);
@@ -2005,7 +2010,7 @@ dcl_usptmk(obj, cside, islct, pos, n)
       n = rb_funcall(n, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_islct = NUM2INT(islct);
     i_n = NUM2INT(n);
     i_pos = dcl_obj2crealary(pos);
@@ -2041,9 +2046,9 @@ dcl_uspttl(obj, cside, islct, cttl, pos)
       pos = rb_funcall(pos, rb_intern("to_f"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_islct = NUM2INT(islct);
-    i_cttl = STR2CSTR(cttl);
+    i_cttl = StringValuePtr(cttl);
     i_pos = (real)NUM2DBL(pos);
 
 
@@ -2065,7 +2070,7 @@ dcl_usrget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     usrget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -2091,7 +2096,7 @@ dcl_usrset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -2115,7 +2120,7 @@ dcl_usrstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -2153,7 +2158,7 @@ dcl_usrqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     usrqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -2277,7 +2282,7 @@ dcl_usrqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     usrqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -2299,7 +2304,7 @@ dcl_ussaxs(obj, cside)
       cside = rb_funcall(cside, rb_intern("to_str"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
 
 
     ussaxs_(i_cside, (ftnlen)strlen(i_cside));
@@ -2322,7 +2327,7 @@ dcl_usxinz(obj, csa)
       csa = rb_funcall(csa, rb_intern("to_str"), 0);
     }
 
-    i_csa = STR2CSTR(csa);
+    i_csa = StringValuePtr(csa);
 
 
     usxinz_(i_csa, &o_faca, &o_offa, (ftnlen)strlen(i_csa));
@@ -2359,7 +2364,7 @@ dcl_usyinz(obj, csa)
       csa = rb_funcall(csa, rb_intern("to_str"), 0);
     }
 
-    i_csa = STR2CSTR(csa);
+    i_csa = StringValuePtr(csa);
 
 
     usyinz_(i_csa, &o_faca, &o_offa, (ftnlen)strlen(i_csa));
