@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -84,7 +89,7 @@ dcl_uzpqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzpqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -232,7 +237,7 @@ dcl_uzpqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzpqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -285,7 +290,7 @@ dcl_uzcget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -313,8 +318,8 @@ dcl_uzcset(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     uzcset_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -337,8 +342,8 @@ dcl_uzcstx(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     uzcstx_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -375,7 +380,7 @@ dcl_uzcqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzcqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -480,7 +485,7 @@ dcl_uzcsvl(obj, idx, cval)
     }
 
     i_idx = NUM2INT(idx);
-    i_cval = STR2CSTR(cval);
+    i_cval = StringValuePtr(cval);
 
 
     uzcsvl_(&i_idx, i_cval, (ftnlen)strlen(i_cval));
@@ -501,7 +506,7 @@ dcl_uzcqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzcqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -563,7 +568,7 @@ dcl_uziget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uziget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -589,7 +594,7 @@ dcl_uziset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -613,7 +618,7 @@ dcl_uzistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -651,7 +656,7 @@ dcl_uziqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uziqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -775,7 +780,7 @@ dcl_uziqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uziqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -837,7 +842,7 @@ dcl_uzlget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzlget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -860,7 +865,7 @@ dcl_uzlset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -881,7 +886,7 @@ dcl_uzlstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -919,7 +924,7 @@ dcl_uzlqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzlqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1040,7 +1045,7 @@ dcl_uzlqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzlqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1102,7 +1107,7 @@ dcl_uzrget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzrget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -1128,7 +1133,7 @@ dcl_uzrset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1152,7 +1157,7 @@ dcl_uzrstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1190,7 +1195,7 @@ dcl_uzrqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzrqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1314,7 +1319,7 @@ dcl_uzrqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uzrqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
