@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -72,8 +77,8 @@ dcl_lchreq(obj, ch1, ch2)
       ch2 = rb_funcall(ch2, rb_intern("to_str"), 0);
     }
 
-    i_ch1 = STR2CSTR(ch1);
-    i_ch2 = STR2CSTR(ch2);
+    i_ch1 = StringValuePtr(ch1);
+    i_ch2 = StringValuePtr(ch2);
 
 
     o_rtn_val = lchreq_(i_ch1, i_ch2, (ftnlen)strlen(i_ch1), (ftnlen)strlen(i_ch2));
@@ -103,9 +108,9 @@ dcl_msgdmp(obj, clev, csub, cmsg)
       cmsg = rb_funcall(cmsg, rb_intern("to_str"), 0);
     }
 
-    i_clev = STR2CSTR(clev);
-    i_csub = STR2CSTR(csub);
-    i_cmsg = STR2CSTR(cmsg);
+    i_clev = StringValuePtr(clev);
+    i_csub = StringValuePtr(csub);
+    i_cmsg = StringValuePtr(cmsg);
 
 
     msgdmp_(i_clev, i_csub, i_cmsg, (ftnlen)strlen(i_clev), (ftnlen)strlen(i_csub), (ftnlen)strlen(i_cmsg));
@@ -132,7 +137,7 @@ dcl_mszdmp(obj, cmsg, iunit, lnsize)
       lnsize = rb_funcall(lnsize, rb_intern("to_i"), 0);
     }
 
-    i_cmsg = STR2CSTR(cmsg);
+    i_cmsg = StringValuePtr(cmsg);
     i_iunit = NUM2INT(iunit);
     i_lnsize = NUM2INT(lnsize);
 
@@ -155,7 +160,7 @@ dcl_glcget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -183,8 +188,8 @@ dcl_glcset(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     glcset_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -207,8 +212,8 @@ dcl_glcstx(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     glcstx_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -229,7 +234,7 @@ dcl_glqfnm(obj, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cpara = STR2CSTR(cpara);
+    i_cpara = StringValuePtr(cpara);
 
     o_cfname= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cfname, '\0', DFLT_SIZE+1);
@@ -336,7 +341,7 @@ dcl_glpqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     glpqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -484,7 +489,7 @@ dcl_glpqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     glpqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -508,7 +513,7 @@ dcl_gliget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     gliget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -534,7 +539,7 @@ dcl_gliset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -558,7 +563,7 @@ dcl_glistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -580,7 +585,7 @@ dcl_gllget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     gllget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -603,7 +608,7 @@ dcl_gllset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -624,7 +629,7 @@ dcl_gllstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -660,8 +665,8 @@ dcl_rtienv(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtienv_(i_cpfix, i_cp, &o_ipara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -689,8 +694,8 @@ dcl_rtlenv(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtlenv_(i_cpfix, i_cp, &o_lpara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -718,8 +723,8 @@ dcl_rtrenv(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtrenv_(i_cpfix, i_cp, &o_rpara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -747,8 +752,8 @@ dcl_rtcenv(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -774,7 +779,7 @@ dcl_rlienv(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rlienv_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -798,7 +803,7 @@ dcl_rllenv(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rllenv_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -822,7 +827,7 @@ dcl_rlrenv(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rlrenv_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -846,7 +851,7 @@ dcl_rlcenv(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -872,7 +877,7 @@ dcl_glrget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     glrget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -898,7 +903,7 @@ dcl_glrset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -922,7 +927,7 @@ dcl_glrstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -960,7 +965,7 @@ dcl_gllqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     gllqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1081,7 +1086,7 @@ dcl_gllqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     gllqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1126,7 +1131,7 @@ dcl_rtiget(obj, cpfix, cps, max)
       max = rb_funcall(max, rb_intern("to_i"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
+    i_cpfix = StringValuePtr(cpfix);
     i_max = NUM2INT(max);
     i_cps = dcl_obj2ccharary(cps, (i_max*8), 8);
 
@@ -1167,7 +1172,7 @@ dcl_rtlget(obj, cpfix, cps, max)
       max = rb_funcall(max, rb_intern("to_i"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
+    i_cpfix = StringValuePtr(cpfix);
     i_max = NUM2INT(max);
     i_cps = dcl_obj2ccharary(cps, (i_max*8), 8);
 
@@ -1208,7 +1213,7 @@ dcl_rtrget(obj, cpfix, cps, max)
       max = rb_funcall(max, rb_intern("to_i"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
+    i_cpfix = StringValuePtr(cpfix);
     i_max = NUM2INT(max);
     i_cps = dcl_obj2ccharary(cps, (i_max*8), 8);
 
@@ -1249,7 +1254,7 @@ dcl_rtcget(obj, cpfix, cps, max)
       max = rb_funcall(max, rb_intern("to_i"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
+    i_cpfix = StringValuePtr(cpfix);
     i_max = NUM2INT(max);
     i_cps = dcl_obj2ccharary(cps, (i_max*8), 8);
 
@@ -1435,8 +1440,8 @@ dcl_rtiopt(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtiopt_(i_cpfix, i_cp, &o_ipara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -1464,8 +1469,8 @@ dcl_rtlopt(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtlopt_(i_cpfix, i_cp, &o_lpara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -1493,8 +1498,8 @@ dcl_rtropt(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtropt_(i_cpfix, i_cp, &o_rpara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -1522,8 +1527,8 @@ dcl_rtcopt(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -1549,7 +1554,7 @@ dcl_rliopt(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rliopt_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -1573,7 +1578,7 @@ dcl_rllopt(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rllopt_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -1597,7 +1602,7 @@ dcl_rlropt(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rlropt_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -1621,7 +1626,7 @@ dcl_rlcopt(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -1661,8 +1666,8 @@ dcl_rtixfl(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtixfl_(i_cpfix, i_cp, &o_ipara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -1690,8 +1695,8 @@ dcl_rtlxfl(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtlxfl_(i_cpfix, i_cp, &o_lpara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -1719,8 +1724,8 @@ dcl_rtrxfl(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
 
     rtrxfl_(i_cpfix, i_cp, &o_rpara, (ftnlen)strlen(i_cpfix), (ftnlen)strlen(i_cp));
@@ -1748,8 +1753,8 @@ dcl_rtcxfl(obj, cpfix, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cpfix = STR2CSTR(cpfix);
-    i_cp = STR2CSTR(cp);
+    i_cpfix = StringValuePtr(cpfix);
+    i_cp = StringValuePtr(cp);
 
     o_cval= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cval, '\0', DFLT_SIZE+1);
@@ -1775,7 +1780,7 @@ dcl_rlixfl(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rlixfl_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -1799,7 +1804,7 @@ dcl_rllxfl(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rllxfl_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -1823,7 +1828,7 @@ dcl_rlrxfl(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     rlrxfl_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -1847,7 +1852,7 @@ dcl_rlcxfl(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
     o_cval= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cval, '\0', DFLT_SIZE+1);
@@ -1871,7 +1876,7 @@ dcl_prcopn(obj, cproc)
       cproc = rb_funcall(cproc, rb_intern("to_str"), 0);
     }
 
-    i_cproc = STR2CSTR(cproc);
+    i_cproc = StringValuePtr(cproc);
 
 
     prcopn_(i_cproc, (ftnlen)strlen(i_cproc));
@@ -1890,7 +1895,7 @@ dcl_prccls(obj, cproc)
       cproc = rb_funcall(cproc, rb_intern("to_str"), 0);
     }
 
-    i_cproc = STR2CSTR(cproc);
+    i_cproc = StringValuePtr(cproc);
 
 
     prccls_(i_cproc, (ftnlen)strlen(i_cproc));
