@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -74,10 +79,10 @@ dcl_chngc(obj, ch, ca, cb)
       cb = rb_funcall(cb, rb_intern("to_str"), 0);
     }
 
-    io_ch = ALLOCA_N(char, strlen(STR2CSTR(ch))+1);
-    strcpy(io_ch, STR2CSTR(ch));
-    i_ca = STR2CSTR(ca);
-    i_cb = STR2CSTR(cb);
+    io_ch = ALLOCA_N(char, strlen(StringValuePtr(ch))+1);
+    strcpy(io_ch, StringValuePtr(ch));
+    i_ca = StringValuePtr(ca);
+    i_cb = StringValuePtr(cb);
 
 
     chngc_(io_ch, i_ca, i_cb, (ftnlen)strlen(io_ch), (ftnlen)strlen(i_ca), (ftnlen)strlen(i_cb));
@@ -111,11 +116,11 @@ dcl_chngi(obj, ch, ca, ii, cfmt)
       cfmt = rb_funcall(cfmt, rb_intern("to_str"), 0);
     }
 
-    io_ch = ALLOCA_N(char, strlen(STR2CSTR(ch))+1);
-    strcpy(io_ch, STR2CSTR(ch));
-    i_ca = STR2CSTR(ca);
+    io_ch = ALLOCA_N(char, strlen(StringValuePtr(ch))+1);
+    strcpy(io_ch, StringValuePtr(ch));
+    i_ca = StringValuePtr(ca);
     i_ii = NUM2INT(ii);
-    i_cfmt = STR2CSTR(cfmt);
+    i_cfmt = StringValuePtr(cfmt);
 
 
     chngi_(io_ch, i_ca, &i_ii, i_cfmt, (ftnlen)strlen(io_ch), (ftnlen)strlen(i_ca), (ftnlen)strlen(i_cfmt));
@@ -149,11 +154,11 @@ dcl_chngr(obj, ch, ca, rr, cfmt)
       cfmt = rb_funcall(cfmt, rb_intern("to_str"), 0);
     }
 
-    io_ch = ALLOCA_N(char, strlen(STR2CSTR(ch))+1);
-    strcpy(io_ch, STR2CSTR(ch));
-    i_ca = STR2CSTR(ca);
+    io_ch = ALLOCA_N(char, strlen(StringValuePtr(ch))+1);
+    strcpy(io_ch, StringValuePtr(ch));
+    i_ca = StringValuePtr(ca);
     i_rr = (real)NUM2DBL(rr);
-    i_cfmt = STR2CSTR(cfmt);
+    i_cfmt = StringValuePtr(cfmt);
 
 
     chngr_(io_ch, i_ca, &i_rr, i_cfmt, (ftnlen)strlen(io_ch), (ftnlen)strlen(i_ca), (ftnlen)strlen(i_cfmt));
